Murko Integration
=================

The `Murko system <https://github.com/MartinSavko/murko>`_ uses ML to analyse images of sample from optical cameras and determine where the sample is.

Its integration at DLS, using Bluesky, is still a work in progress but this documentation aims to give an overview of how it works.


.. grid:: 2
    :gutter: 2

    .. grid-item-card:: :material-regular:`apartment;3em`

        .. toctree::
            :caption: Explanations
            :maxdepth: 1

            explanations/architecture

        +++

        Explanations of how and why the architecture is why it is.
